##  Creating New Fact Sheets and Relations from Within the Canvas
In Free Draw, you can create new fact sheets and new relations between fact sheets directly within the diagram.
  1. Right-click on any shape that is not yet associated with a fact sheet and select Create new fact sheet. Then select the fact sheet type you would like to convert your shape to.
  2. Edit the text inside the shape. The text that you provide within the shape will serve as the new fact sheet name.
  3. To add your newly created fact sheet to the Inventory, click on the Updates button in the top right corner. Select the fact sheets you want to create, then click Apply updates.
  4. The new fact sheet has now been added to the Inventory, and a confirmation message is displayed.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275635f97a441014af839397ded50c6b_LowRes.gif)
**Note**
  * A default naming scheme will be applied to the shapes if no custom name is provided. i.e. Business Capability 1, Business Capability 2, Application 1, Application 2 etc.
  * A + icon will be displayed in the top right corner of the newly created fact sheet, and it will remain there until the fact sheet is added to the Inventory through the Updates function.


**Note**
Fact sheet and relation creation feature are only available in Free Draw and is currently not yet available in Data Flow.
If you have more than one fact sheet in the diagram, you can establish relations between them by joining them with any connector shape (e.g., arrows, dotted lines, etc.).
  1. Draw a connector shape between two fact sheet shapes.
  2. Right-click on the connector shape and select Create new relation. Then select a relation type you would like to establish.
  3. To add your newly created relation to the Inventory, click on the Updates button link in the top right corner. Select the relations you want to create, then click Apply updates.
  4. A new relation has now been added to the Inventory, and a confirmation message will be displayed.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274abaed7a441014b045af95fb836481_LowRes.gif)
